@@ -5,7 +5,7 @@ plot.survAUC <- function(x, col="red", type="l", ylim=c(0,1),
 		plot(x$times, x$auc, ylim=ylim, main=main, xlab=xlab, ylab=ylab, col=col, type=type, ...)
 	}
 	else{
-		lines(x$times, x$auc, col=col, ...)
+	  graphics::lines(x$times, x$auc, col=col, ...)
 	}
 }
 
@@ -20,7 +20,7 @@ xlab="Time",ylab="Prediction error", main="Time-dependent Prediction Error", add
 		plot(x$times, x$error, ylim=ylim, main=main, xlab=xlab, ylab=ylab, col=col, type=type, ...)
 	}
 	else{
-		lines(x$times, x$error, col=col, ...)
+	  graphics::lines(x$times, x$error, col=col, ...)
 	}
 }
 
